streaming_config_from

Function streaming_config_from 

pub fn streaming_config_from(app: &AppConfig) -> StreamingConfig
Convert an AppConfig reference to a StreamingConfig.

This is a free function because the orphan rule prevents impl From<&AppConfig> for StreamingConfig when both types are defined in foreign crates.